==> react-native-cometchat-calling-component-1.0.41.tgz: package/components/VideoButton.js <==
import React, {Component} from 'react';
import { View, TouchableOpacity, Image } from 'react-native';
import JitsiManager from '../lib/JitsiManager';
import { connect } from 'react-redux';
import data from '../actions';

class VideoButton extends Component{
    constructor(props){
        super(props);
        this.onMuteVideo = this.onMuteVideo.bind(this);
        this.onUnMuteVideo = this.onUnMuteVideo.bind(this);
    }

    onMuteVideo(){
        this.props.changeVideoState(true);
        this.props.onMuteVideo();
    }

    onUnMuteVideo(){
        this.props.changeVideoState(false);
        this.props.onUnMuteVideo();
    }

    renderVideoMuteIcon(){
        return <TouchableOpacity onPress={()=>this.onUnMuteVideo()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_video_mute.png')}/></TouchableOpacity>;
    }

    renderVideoUnMuteIcon(){
        return <TouchableOpacity onPress={()=>this.onMuteVideo()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_video_unmute.png')}/></TouchableOpacity>;
    }

    render(){
        return(
            <View style={this.style.lt_control_view}>
                { this.props.videoMute ? this.renderVideoMuteIcon() : this.renderVideoUnMuteIcon() }
            </View>
        )
    }

    style = {
        lt_control_icon: { width: 28, height: 28 },
        lt_control_view: { width: 48, height: 48, margin: 8, backgroundColor: 'blue', borderRadius: 50, alignItems: 'center', justifyContent:'center' }
    };
}

function mapStateToProps (state) {
    return {
        videoMute: state.tracks.videoMute
    }
}
  
function mapDispatchToProps (dispatch) {
    return {
        onMuteVideo: () => JitsiManager.onMuteVideo(),
        onUnMuteVideo: () => JitsiManager.onUnmuteVideo(),
        changeVideoState: (video) => dispatch(data.changeVideoState(video))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(VideoButton)

==> react-native-cometchat-calling-component-1.1.2.tgz: package/components/VideoButton.js <==
import React, {Component} from 'react';
import { View, TouchableOpacity, Image } from 'react-native';
import JitsiManager from '../lib/JitsiManager';
import { connect } from 'react-redux';
import data from '../actions';

class VideoButton extends Component{
    constructor(props){
        super(props);
        this.onMuteVideo = this.onMuteVideo.bind(this);
        this.onUnMuteVideo = this.onUnMuteVideo.bind(this);
    }

    onMuteVideo(){
        this.props.changeVideoState(true);
        this.props.onMuteVideo();
    }

    onUnMuteVideo(){
        this.props.changeVideoState(false);
        this.props.onUnMuteVideo();
    }

    renderVideoMuteIcon(){
        return <TouchableOpacity onPress={()=>this.onUnMuteVideo()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_video_mute.png')}/></TouchableOpacity>;
    }

    renderVideoUnMuteIcon(){
        return <TouchableOpacity onPress={()=>this.onMuteVideo()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_video_unmute.png')}/></TouchableOpacity>;
    }

    render(){
        return(
            <View style={this.style.lt_control_view}>
                { this.props.videoMute ? this.renderVideoMuteIcon() : this.renderVideoUnMuteIcon() }
            </View>
        )
    }

    style = {
        lt_control_icon: { width: 30, height: 30 },
        lt_control_view: { width: 60, height: 60, margin: 10, backgroundColor: '#4d4c4f', borderRadius: 50, alignItems: 'center', justifyContent:'center' }
    };
}

function mapStateToProps (state) {
    return {
        videoMute: state.tracks.videoMute
    }
}
  
function mapDispatchToProps (dispatch) {
    return {
        onMuteVideo: () => JitsiManager.onMuteVideo(),
        onUnMuteVideo: () => JitsiManager.onUnmuteVideo(),
        changeVideoState: (video) => dispatch(data.changeVideoState(video))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(VideoButton)
